pub struct EpochInfo {
pub epoch_id: EpochId,
pub rng_seed: u64,
pub tags: TagList,
pub summary: String,
pub events: Vec<Entity>,
pub characters: Vec<Entity>,
pub towns: Vec<Entity>,
pub calamities: Vec<Entity>,
pub blockers: Vec<Entity>,
}Expand description
The metadata file stored inside each epoch directory
(epoch/<epoch_id>/.epochinfo).
It contains only the information that is needed for the engine to
reconstruct the state of that particular epoch (seed, selected
events, parent link, etc.). The full world data will be kept in
separate storage (e.g. world.json) but is for stored here.
Fields
epoch_id: EpochIdThe ID of this epoch - should match the directory name.
rng_seed: u64RNG seed that was used to generate randomised data for this epoch. Keeping it in the file guarantees repeatable behaviour when replaying the same epoch.
Optional tags that help identify the epoch (e.g. "Winter-B").
summary: StringHuman-readable description or summary, useful for the log command.
events: Vec<Entity>The list of events currently in progress
characters: Vec<Entity>The list of characters currently present
towns: Vec<Entity>The list of towns currently present
calamities: Vec<Entity>The list of calamities currently present
blockers: Vec<Entity>The list of blockers currently present
Implementations
Sourceimpl EpochInfo
impl EpochInfo
Sourcepub fn create_subfolders(&self) -> Result<(), EpochError>
pub fn create_subfolders(&self) -> Result<(), EpochError>
Create all subfolders as needed
This command can be safely used even if the folder already exists
Sourceimpl EpochInfo
impl EpochInfo
Sourcepub fn find_entity_of_type(
&self,
entity_to_find: &Option<EntityIdentifier>,
e_type: &EntityType,
) -> Result<&Entity, EpochError>
pub fn find_entity_of_type( &self, entity_to_find: &Option<EntityIdentifier>, e_type: &EntityType, ) -> Result<&Entity, EpochError>
Looks up an entity inside the given epoch_info according to the
supplied arguments.
The function returns a reference to the matching entity or an
EpochError::EntityNotFound if no entity matches.
Arguments
entity_args- The arguments that identify the entity.e_type- The type of entity to look for.epoch_info- The epoch that contains all entities.
Returns
Ok(&Entity)- The entity that matches the arguments.Err(EpochError::EntityNotFound)- No matching entity was found.
Sourcepub fn add_to_links(
&mut self,
target_id: Uuid,
target_t: &EntityType,
link_back: TypedLink,
) -> Result<(), EpochError>
pub fn add_to_links( &mut self, target_id: Uuid, target_t: &EntityType, link_back: TypedLink, ) -> Result<(), EpochError>
Adds a link between two entities inside the epoch.
The link is added to the entity identified by id_to_add_to. If the
target entity is not found, an EntityNotFoundById error is returned.
Sourcepub fn del_from_links(
&mut self,
target_id: Uuid,
target_t: &EntityType,
link_back: TypedLink,
) -> Result<(), EpochError>
pub fn del_from_links( &mut self, target_id: Uuid, target_t: &EntityType, link_back: TypedLink, ) -> Result<(), EpochError>
Removes a link from an entity inside the epoch.
The removal is performed on the target entity (id_to_add_to). If the
target entity cannot be found, an EpochError::EntityNotFoundById error
is returned. The removal itself is delegated to the entity’s
del_from_links method, which silently ignores missing links.
Sourcepub fn find_any_entity(
&self,
id: EntityIdentifier,
) -> Result<&Entity, EpochError>
pub fn find_any_entity( &self, id: EntityIdentifier, ) -> Result<&Entity, EpochError>
Find an entity by its UUID.
This function searches the currently loaded epoch for an entity whose
id matches the supplied Uuid. It looks in both the events, towns
and characters collections of the epoch.
Arguments
id- TheUuidof the entity to locate.
Returns
Ok(&Entity)- Reference to the entity if it is present in the current epoch.Err(EpochError::EntityNotFoundById(id))- No entity with the supplied UUID exists in the epoch.
Sourcepub fn find_entity_strict(
&self,
id: Uuid,
strict: Option<EntityType>,
) -> Result<&Entity, EpochError>
pub fn find_entity_strict( &self, id: Uuid, strict: Option<EntityType>, ) -> Result<&Entity, EpochError>
Find an entity from an Uuid
Sourcepub fn find_entity_strict_as_mut(
&mut self,
id: Uuid,
strict: Option<EntityType>,
) -> Result<&mut Entity, EpochError>
pub fn find_entity_strict_as_mut( &mut self, id: Uuid, strict: Option<EntityType>, ) -> Result<&mut Entity, EpochError>
Find an entity from an Uuid
Sourcepub fn vec_entities(&self, e_type: &EntityType) -> &Vec<Entity>
pub fn vec_entities(&self, e_type: &EntityType) -> &Vec<Entity>
Returns a slice over the entities of the requested type from the given EpochInfo.
The function matches the supplied e_type to the appropriate collection
inside epoch_info. For unimplemented entity types the call will panic
because of the todo!() placeholder.
Sourcepub fn remove_entity(
&mut self,
entity_identifier: &Option<EntityIdentifier>,
e_type: &EntityType,
) -> Result<Entity, EpochError>
pub fn remove_entity( &mut self, entity_identifier: &Option<EntityIdentifier>, e_type: &EntityType, ) -> Result<Entity, EpochError>
Removes an entity from the epoch’s collection and returns it.
The function looks up the entity that matches the supplied entity_identifier
in the collection corresponding to e_type. If the entity is found, it
is removed using swap_remove and returned. When the entity cannot be
located, an EpochError::EntityNotFound is returned.
Sourcepub fn vec_entities_mut(&mut self, e_type: &EntityType) -> &mut Vec<Entity>
pub fn vec_entities_mut(&mut self, e_type: &EntityType) -> &mut Vec<Entity>
Returns a mutable slice over the entities of the requested type from the given
EpochInfo.
Like vec_entities, this function selects the appropriate collection
based on e_type. Unimplemented variants will panic due to the todo!().
Sourcepub fn iter_all_entities_mut(&mut self) -> impl Iterator<Item = &mut Entity>
pub fn iter_all_entities_mut(&mut self) -> impl Iterator<Item = &mut Entity>
Returns an iterator over mutable references to all entities that are currently
stored in the EpochInfo container.
Sourcepub fn resolve_position(
&self,
position: &PositionIdentifier,
) -> Result<Position, EpochError>
pub fn resolve_position( &self, position: &PositionIdentifier, ) -> Result<Position, EpochError>
Get the position of an entity either directly or cloning one from an epoch
Sourcepub fn swap_entity(&mut self, entity: Entity) -> Result<Entity, EpochError>
pub fn swap_entity(&mut self, entity: Entity) -> Result<Entity, EpochError>
Swap an entity with an updated one